/**
 * Removes invalid tags from a metadata object and returns a new object.
 *
 * This function currently removes tags that have `null` or `undefined` values.
 * Removing these values is important to prevent errors when processing
 * the metadata, such as when calling `naturalizeDataset(...)`.
 *
 * The performance of this function has been considered. Validating each
 * tag ID with a regex significantly reduces the function's speed, so this
 * approach is avoided. The function is designed to be efficient, with an
 * average runtime of around +12ms per 1000 images, though this can vary
 * depending on the machine.
 *
 * @param srcMetadata - The source metadata object containing the tags.
 * @returns A new metadata object with invalid tags removed.
 */
export const removeInvalidTags = (
  srcMetadata: Record<string, any>
): Record<string, any> => {
  const dstMetadata: Record<string, any> = Object.create(null);
  const tagIds = Object.keys(srcMetadata);
  let tagValue: any;

  tagIds.forEach((tagId) => {
    tagValue = srcMetadata[tagId];

    if (tagValue !== undefined && tagValue !== null) {
      dstMetadata[tagId] = tagValue;
    }
  });

  return dstMetadata;
};
