import { useEffect, useRef } from "react";
import { Enums, RenderingEngine, cache } from "@cornerstonejs/core";
import { initCornerstone } from "../CornerstoneDicomLoader/init";
import { createImageIdsAndCacheMetaData } from "../CornerstoneDicomLoader/createImageIdsAndCacheMetaData";
import {
  IStackViewport,
  PublicViewportInput,
} from "@cornerstonejs/core/dist/types/types";

interface StackViewerProps {
  children?: JSX.Element;
}

const renderingEngineId = "myRenderingEngine";
const viewportId = "CT_STACK";

const { ViewportType } = Enums;

const StudyInstanceUID =
  "1.2.840.113564.345049290535.9692.637552042156233117.433089";
const SeriesInstanceUID =
  "1.3.12.2.1107.5.1.4.76315.30000021042706150001900118311";

export const StackViewer = (props: StackViewerProps) => {
  const dicomRef = useRef(null);

  const run = async () => {
    await initCornerstone();
    // Get Cornerstone imageIds and fetch metadata into RAM
    const imageIds = await createImageIdsAndCacheMetaData({
      StudyInstanceUID,
      SeriesInstanceUID,
      wadoRsRoot: "/dicom-web",
    });

    const renderingEngine = new RenderingEngine(renderingEngineId);

    const viewportInput = {
      viewportId,
      type: ViewportType.STACK,
      element: dicomRef.current,
    } as unknown as PublicViewportInput;

    renderingEngine.enableElement(viewportInput);

    const viewport = renderingEngine.getViewport(viewportId) as IStackViewport;

    const stack = imageIds;

    await viewport.setStack(stack);
    const currentImageIdIndex = viewport.getCurrentImageIdIndex();
    const numImages = viewport.getImageIds().length;
    let newImageIdIndex = currentImageIdIndex + 1;
    newImageIdIndex = Math.min(newImageIdIndex, numImages - 1);
    viewport.setImageIdIndex(newImageIdIndex);
  };

  useEffect(() => {
    run();
  }, []);

  return (
    <div>
      <div ref={dicomRef} style={{ width: 400, height: 400 }}></div>
    </div>
  );
};
